@@ -4,11 +4,9 @@ A general tool for plotting, slicing, and analyzing xarray DataArrays.
 
 # ----------------------------------------------------------------------------------
 
-#from iautil.utilities.ui import DataArrayImageView
 import numpy as np
 import pyqtgraph as pg
 from pyqtgraph import dockarea, QtGui
-import sys
 import xarray as xr
 
 # ----------------------------------------------------------------------------------
@@ -50,7 +48,8 @@ class ImageToolWidget(QtGui.QWidget):
     def __init__(self, data_array: xr.DataArray) -> None:
         super(ImageToolWidget, self).__init__()
 
-        self.setMinimumSize(640, 480)
+        self.setWindowTitle("ImageTool")
+        self.setMinimumSize(900, 675)
 
         self.data_array = data_array
 
@@ -110,6 +109,7 @@ class ImageToolWidget(QtGui.QWidget):
         )
 
         self.dock_area.addDock(self.data_array_image_view_dock)
-        self.dock_area.addDock(self.controller_widget_dock)
+        self.dock_area.addDock(self.controller_widget_dock, "bottom", 
+            self.data_array_image_view_dock)
 
 # ----------------------------------------------------------------------------------
\ No newline at end of file
